[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-commits
Subject:    [amarok] /: Spelling fixes.
From:       Modestas Vainius <modax () debian ! org>
Date:       2011-07-24 6:44:12
Message-ID: 20110724064412.BDDD9A60A6 () git ! kde ! org
[Download RAW message or body]

Git commit 1cad454877f9700df7806eb3bd186092b8f6e523 by Modestas Vainius.
Committed on 24/07/2011 at 08:22.
Pushed by modax into branch 'master'.

Spelling fixes.

recieved -> received
Calender -> Calendar
writeable -> writable

M  +1    -1    src/core-impl/collections/mediadevicecollection/MediaDeviceCollectionLocation.cpp
 M  +1    -1    src/core-impl/collections/db/DatabaseMeta.h
M  +2    -2    src/core/collections/CollectionLocation.cpp
M  +1    -1    src/context/applets/upcomingevents/UpcomingEventsApplet.cpp
M  +6    -6    src/core/collections/CollectionLocation.h
M  +1    -1    src/core-impl/collections/db/sql/SqlMeta.h
M  +6    -6    src/core-impl/collections/db/sql/SqlCollectionLocation.cpp
M  +3    -3    src/core-impl/collections/support/CollectionLocationDelegateImpl.cpp
M  +3    -3    src/core-impl/collections/playdarcollection/support/Query.h
M  +1    -1    supplementary_scripts/databasescripts/backupDatabase.rb
M  +6    -6    src/core-impl/collections/playdarcollection/support/Query.cpp

http://commits.kde.org/amarok/1cad454877f9700df7806eb3bd186092b8f6e523

diff --git a/src/context/applets/upcomingevents/UpcomingEventsApplet.cpp \
b/src/context/applets/upcomingevents/UpcomingEventsApplet.cpp index 8309526..9664201 \
                100644
--- a/src/context/applets/upcomingevents/UpcomingEventsApplet.cpp
+++ b/src/context/applets/upcomingevents/UpcomingEventsApplet.cpp
@@ -529,7 +529,7 @@ UpcomingEventsApplet::viewCalendar()
     UpcomingEventsStackItem *stackItem = m_stack->create( QLatin1String("calendar") \
                );
     UpcomingEventsCalendarWidget *calendar = new UpcomingEventsCalendarWidget( \
stackItem );  stackItem->setIcon( KIcon( "view-calendar" ) );
-    stackItem->setTitle( i18n( "Events Calender" ) );
+    stackItem->setTitle( i18n( "Events Calendar" ) );
     stackItem->setWidget( calendar );
     stackItem->setMinimumWidth( 50 );
     stackItem->showCloseButton();
diff --git a/src/core-impl/collections/db/DatabaseMeta.h \
b/src/core-impl/collections/db/DatabaseMeta.h index 10e1dbe..5fbfaaa 100644
--- a/src/core-impl/collections/db/DatabaseMeta.h
+++ b/src/core-impl/collections/db/DatabaseMeta.h
@@ -77,7 +77,7 @@ class AMAROK_DATABASECOLLECTION_EXPORT_TESTS DatabaseTrack : public \
Meta::Track  
         /** true if there is a collection and the file exists on disk */
         virtual bool isPlayable() const;
-        /** true if there is a collection, the file exists on disk and is writeable \
*/ +        /** true if there is a collection, the file exists on disk and is \
writable */  virtual bool isEditable() const;
 
         virtual Meta::AlbumPtr album() const { return m_album; }
diff --git a/src/core-impl/collections/db/sql/SqlMeta.h \
b/src/core-impl/collections/db/sql/SqlMeta.h index cbe64fe..c0253ac 100644
--- a/src/core-impl/collections/db/sql/SqlMeta.h
+++ b/src/core-impl/collections/db/sql/SqlMeta.h
@@ -93,7 +93,7 @@ class AMAROK_SQLCOLLECTION_EXPORT_TESTS SqlTrack : public \
Meta::Track  
         /** true if there is a collection and the file exists on disk */
         virtual bool isPlayable() const;
-        /** true if there is a collection, the file exists on disk and is writeable \
*/ +        /** true if there is a collection, the file exists on disk and is \
writable */  virtual bool isEditable() const;
 
         virtual Meta::AlbumPtr album() const;
diff --git a/src/core-impl/collections/mediadevicecollection/MediaDeviceCollectionLocation.cpp \
b/src/core-impl/collections/mediadevicecollection/MediaDeviceCollectionLocation.cpp \
                index cf34b51..8a3879c 100644
--- a/src/core-impl/collections/mediadevicecollection/MediaDeviceCollectionLocation.cpp
                
+++ b/src/core-impl/collections/mediadevicecollection/MediaDeviceCollectionLocation.cpp
 @@ -52,7 +52,7 @@ MediaDeviceCollectionLocation::prettyLocation() const
 }
 
 // NOTE: must be overridden by child class if
-// it is writeable
+// it is writable
 bool
 MediaDeviceCollectionLocation::isWritable() const
 {
diff --git a/src/core-impl/collections/playdarcollection/support/Query.cpp \
b/src/core-impl/collections/playdarcollection/support/Query.cpp index \
                27ede72..98a1eb5 100644
--- a/src/core-impl/collections/playdarcollection/support/Query.cpp
+++ b/src/core-impl/collections/playdarcollection/support/Query.cpp
@@ -42,14 +42,14 @@ namespace Playdar
     , m_album( QString( "" ) )
     , m_title( QString( "" ) )
     , m_solved( false )
-    , m_recievedFirstResults( false )
+    , m_receivedFirstResults( false )
     , m_trackList( )
     {
         DEBUG_BLOCK
         
         if( m_waitForSolution )
         {
-            m_recievedFirstResults = true;
+            m_receivedFirstResults = true;
             m_controller.data()->getResultsLongPoll( this );
         }
         else
@@ -159,7 +159,7 @@ namespace Playdar
         }
         if( parsedResults.value( "qid" ) != m_qid )
         {
-            debug() << "A query recieved the wrong results from Playdar...";
+            debug() << "A query received the wrong results from Playdar...";
             emit playdarError( Playdar::Controller::ErrorState( 5 ) );
             return;
         }
@@ -216,14 +216,14 @@ namespace Playdar
             emit newTrackAdded( aTrack );
         }
         
-        if( m_recievedFirstResults || m_solved )
+        if( m_receivedFirstResults || m_solved )
         {
-            m_recievedFirstResults = true;
+            m_receivedFirstResults = true;
             emit queryDone( this, m_trackList );
         }
         else
         {
-            m_recievedFirstResults = true;
+            m_receivedFirstResults = true;
             m_controller.data()->getResultsLongPoll( this );
         }
     }
diff --git a/src/core-impl/collections/support/CollectionLocationDelegateImpl.cpp \
b/src/core-impl/collections/support/CollectionLocationDelegateImpl.cpp index \
                e930b91..349464c 100644
--- a/src/core-impl/collections/support/CollectionLocationDelegateImpl.cpp
+++ b/src/core-impl/collections/support/CollectionLocationDelegateImpl.cpp
@@ -95,8 +95,8 @@ void CollectionLocationDelegateImpl::errorDeleting( \
CollectionLocation* loc, con  foreach( Meta::TrackPtr track, tracks )
         files << track->prettyUrl();
 
-    const QString text( i18ncp( "@info", "There was a problem and this track could \
                not be removed. Make sure the directory is writeable.",
-                                "There was a problem and %1 tracks could not be \
removed. Make sure the directory is writeable.", files.count() ) ); +    const \
QString text( i18ncp( "@info", "There was a problem and this track could not be \
removed. Make sure the directory is writable.", +                                \
"There was a problem and %1 tracks could not be removed. Make sure the directory is \
writable.", files.count() ) );  KMessageBox::informationList(0,
                                                              text,
                                                              files,
@@ -107,7 +107,7 @@ void \
CollectionLocationDelegateImpl::notWriteable(CollectionLocation* loc) const  {
     Q_UNUSED( loc )
     Amarok::Components::logger()->longMessage(
-            i18n( "The collection does not have enough free space available or is \
not writeable." ), +            i18n( "The collection does not have enough free space \
available or is not writable." ),  Amarok::Logger::Error );
 }
 
diff --git a/src/core/collections/CollectionLocation.cpp \
b/src/core/collections/CollectionLocation.cpp index 7fd774d..01d0f5b 100644
--- a/src/core/collections/CollectionLocation.cpp
+++ b/src/core/collections/CollectionLocation.cpp
@@ -273,7 +273,7 @@ CollectionLocation::copyUrlsToCollection( const \
                QMap<Meta::TrackPtr, KUrl> &sour
                                           const Transcoding::Configuration \
&configuration )  {
     DEBUG_BLOCK
-    //reimplement in implementations which are writeable
+    //reimplement in implementations which are writable
     Q_UNUSED( sources )
     Q_UNUSED( configuration )
     slotCopyOperationFinished();
@@ -283,7 +283,7 @@ void
 CollectionLocation::removeUrlsFromCollection( const Meta::TrackList &sources )
 {
     DEBUG_BLOCK
-    //reimplement in implementations which are writeable
+    //reimplement in implementations which are writable
     Q_UNUSED( sources )
     slotRemoveOperationFinished();
 }
diff --git a/src/core/collections/CollectionLocation.h \
b/src/core/collections/CollectionLocation.h index cdbd05d..375a858 100644
--- a/src/core/collections/CollectionLocation.h
+++ b/src/core/collections/CollectionLocation.h
@@ -40,7 +40,7 @@ namespace Collections {
     - call prepareCopy or prepareMove on the source CollectionLocation
     - forget about the rest of the workflow
 
-    Implementations which are writeable must reimplement the following methods
+    Implementations which are writable must reimplement the following methods
     - prettyLocation()
     - isWritable()
     - remove( Meta::Track )
@@ -133,13 +133,13 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
         virtual QStringList actualLocation() const;
 
         /**
-            Returns whether the collection location is writeable or not. For \
example, a +            Returns whether the collection location is writable or not. \
                For example, a
             local collection or an ipod collection would return true, a daap \
                collection
             or a service collection false. The value returned by this method \
                indicates
             if it is possible to copy tracks to the collection, and if it is \
generally  possible to remove/delete files from the collection.
-            @return @c true if the collection location is writeable
-            @return @c false if the collection location is not writeable
+            @return @c true if the collection location is writable
+            @return @c false if the collection location is not writable
         */
         virtual bool isWritable() const;
 
@@ -244,7 +244,7 @@ class AMAROK_CORE_EXPORT CollectionLocation : public QObject
         virtual void getKIOCopyableUrls( const Meta::TrackList &tracks );
         /**
             this method is called on the destination. reimplement it if your \
                implementation
-            is writeable. you must call slotCopyOperationFinished() when you are \
done copying +            is writable. you must call slotCopyOperationFinished() when \
you are done copying  the files.
         */
         virtual void copyUrlsToCollection( const QMap<Meta::TrackPtr, KUrl> \
&sources, @@ -252,7 +252,7 @@ class AMAROK_CORE_EXPORT CollectionLocation : public \
QObject  
         /**
            this method is called on the collection you want to remove tracks from.  \
                it must
-           be reimplemented if your collection is writeable and you wish to \
implement +           be reimplemented if your collection is writable and you wish to \
implement  removing tracks
         */
 
diff --git a/supplementary_scripts/databasescripts/backupDatabase.rb \
b/supplementary_scripts/databasescripts/backupDatabase.rb index e654f32..e2c967b \
                100644
--- a/supplementary_scripts/databasescripts/backupDatabase.rb
+++ b/supplementary_scripts/databasescripts/backupDatabase.rb
@@ -42,7 +42,7 @@ unless FileTest.directory?( destination )
 end
 
 unless FileTest.writable_real?( destination )
-    system("dcop", "amarok", "playlist", "popupMessage", "Error: Destination \
directory not writeable.") +    system("dcop", "amarok", "playlist", "popupMessage", \
"Error: Destination directory not writable.")  exit( 1 )
 end
 


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
diff --git a/src/core-impl/collections/db/sql/SqlCollectionLocation.cpp \
b/src/core-impl/collections/db/sql/SqlCollectionLocation.cpp index 8b59804..747102a \
                100644
--- a/src/core-impl/collections/db/sql/SqlCollectionLocation.cpp
+++ b/src/core-impl/collections/db/sql/SqlCollectionLocation.cpp
@@ -85,10 +85,10 @@ SqlCollectionLocation::isWritable() const
     // TODO: This function is also called when removing files to check
     //  if the tracks can be removed. In such a case we should not check the space
 
     // The collection is writeable if there exists a path that has more than
     // 500 MB free space.
     bool path_exists_with_space = false;
-    bool path_exists_writeable = false;
+    bool path_exists_writable = false;
     QStringList folders = actualLocation();
     foreach(QString path, folders)
     {
@@ -108,11 +108,11 @@ SqlCollectionLocation::isWritable() const
 
         QFileInfo info( path );
         if( info.isWritable() )
-            path_exists_writeable = true;
-	debug() << "\tpath_exists_writeable" << path_exists_writeable;
+            path_exists_writable = true;
+	debug() << "\tpath_exists_writable" << path_exists_writable;
 	debug() << "\tpath_exists_with_space" << path_exists_with_space;
     }
-    return path_exists_with_space && path_exists_writeable;
+    return path_exists_with_space && path_exists_writable;
 }
 
 bool
@@ -331,7 +331,7 @@ SqlCollectionLocation::showDestinationDialog( const \
Meta::TrackList &tracks,  
         // since bad things happen when drives become totally full
 	// we make sure there is at least ~500MB left
         // finally, ensure the path is writeable
         debug() << ( freeSpace - transferSize );
         if( ( freeSpace - transferSize ) > 1024*1024*500 && info.isWritable() )
             available_folders << path;
@@ -85,10 +85,10 @@ SqlCollectionLocation::isWritable() const
     //  if the tracks can be removed. In such a case we should not check the space
 
-    // The collection is writeable if there exists a path that has more than
+    // The collection is writable if there exists a path that has more than
     // 500 MB free space.
     bool path_exists_with_space = false;
@@ -331,7 +331,7 @@ SqlCollectionLocation::showDestinationDialog( const \
         // since bad things happen when drives become totally full
 	// we make sure there is at least ~500MB left
-        // finally, ensure the path is writeable
+        // finally, ensure the path is writable
         debug() << ( freeSpace - transferSize );
         if( ( freeSpace - transferSize ) > 1024*1024*500 && info.isWritable() )
diff --git a/src/core-impl/collections/playdarcollection/support/Query.h \
b/src/core-impl/collections/playdarcollection/support/Query.h index abb6d5b..7282f0a \
                100644
--- a/src/core-impl/collections/playdarcollection/support/Query.h
+++ b/src/core-impl/collections/playdarcollection/support/Query.h
@@ -59,7 +59,7 @@ namespace Playdar
             /** @return Track title used in query */
             QString title() const;
             /**
              * @return @c true A track has recieved a 1.00 score
              * @return @c false No track has a 1.00 score
              */
             bool isSolved() const;
@@ -112,9 +112,9 @@ namespace Playdar
             QString m_title;
             bool m_solved;
             
-            bool m_recievedFirstResults;
+            bool m_receivedFirstResults;
             
             Meta::PlaydarTrackList m_trackList;
     };
 }
-#endif
\ No newline at end of file
+#endif
@@ -59,7 +59,7 @@ namespace Playdar
             QString title() const;
             /**
-             * @return @c true A track has recieved a 1.00 score
+             * @return @c true A track has received a 1.00 score
              * @return @c false No track has a 1.00 score
              */